pyIGRF is partially based on ChaosMagPy by Clemens Kloss (DTU Space, Denmark)

ChaosMagPy can be found at: https://doi.org/10.5281/zenodo.3352398

and is based on work by the following authors:

Finlay, C.C., Olsen, N., Kotsiaros, S., Gillet, N. and Toeffner-Clausen, L. (2016),
Recent geomagnetic secular variation from Swarm and ground observatories
as estimated in the CHAOS-6 geomagnetic field model Earth Planets Space,
Vol 68, 112. doi: 10.1186/s40623-016-0486-1

Some of the functions were taken from the 2019 IAGA Summer School examples at
https://github.com/MagneticEarth/IAGA_SummerSchool2019/

This was written by:
- David J. Kerridge (British Geological Survey, UK) 

with  contributions from:
- William Brown (British Geological Survey, UK)
- Grace Cox (British Geological Survey, UK)
- Ashley R.A. Smith (University of Edinburgh, UK) 

